"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createUtilitaryClasses = exports.createPositioningClasses = exports.createPaddingClasses = exports.createMarginClasses = exports.createColorClasses = void 0;
var _mediaQuery = require("../shared/media-query/media-query.js");
var _Color = require("./Color.js");
/**
 * This function is responsible to create class auxiliary for text colors and backgrounds
 * it uses a recursion to get to all possible properties of the theme and extract
 * all the colors used there and generate classes based on the properties names.
 * @param {object | string} currentObject
 * @param {string} property
 */
const getColorProperties = (currentObject, property = '') => {
  if (typeof currentObject === 'string') {
    return `
    .text${property} {
      color: ${currentObject};
    }
    .bg${property} {
      background-color: ${currentObject};
    }
    .fill${property} {
      ${(0, _Color.getFilteredColor)(currentObject)}
    }
  `;
  } else {
    return Object.keys(currentObject).map(currentObjectKey => {
      return getColorProperties(currentObject[currentObjectKey], `${property}-${currentObjectKey}`);
    }).join('');
  }
};
/**
 * This function is responsible to create class auxiliary for text colours and backgrounds
 * and backgrounds using the theme itself.
 * @param {ThemeType} theme
 */
const createColorClasses = theme => {
  return getColorProperties(theme.colors);
};
/**
 * This function is responsible to create class auxiliary for spacings
 * @param {object | string} currentObject
 * @param {string} property
 */
exports.createColorClasses = createColorClasses;
const getSpacingProperties = (spacingObject, property = '', propertyLetter = '', prefix = '') => {
  const escapedPrefix = typeof CSS !== 'undefined' ? CSS.escape(prefix) : prefix;
  return Object.keys(spacingObject).map(currentObjectKey => {
    const lowerCaseObjectKey = currentObjectKey.toLowerCase();
    const value = spacingObject[currentObjectKey];
    return `
      .${escapedPrefix}${propertyLetter}t-${lowerCaseObjectKey} {
        ${property}-top: ${value};
      }

      .${escapedPrefix}${propertyLetter}b-${lowerCaseObjectKey} {
        ${property}-bottom: ${value};
      }

      .${escapedPrefix}${propertyLetter}l-${lowerCaseObjectKey} {
        ${property}-left: ${value};
      }

      .${escapedPrefix}${propertyLetter}r-${lowerCaseObjectKey} {
        ${property}-right: ${value};
      }

      .${escapedPrefix}${propertyLetter}-${lowerCaseObjectKey} {
        ${property}: ${value};
      }

      .${escapedPrefix}${propertyLetter}h-${lowerCaseObjectKey} {
        ${property}-left: ${value};
        ${property}-right: ${value};
      }

      .${escapedPrefix}${propertyLetter}v-${lowerCaseObjectKey} {
        ${property}-top: ${value};
        ${property}-bottom: ${value};
      }
    `;
  }).join('');
};
/**
 * This function is responsible to create class auxiliary for spacings using the theme itself.
 * @param {ThemeType} theme
 */
const createPaddingClasses = (theme, prefix) => {
  return getSpacingProperties(theme.tokens?.padding, 'padding', 'p', prefix);
};
/**
 * This function is responsible to create class auxiliary for spacings using the theme itself.
 * @param {ThemeType} theme
 */
exports.createPaddingClasses = createPaddingClasses;
const createMarginClasses = (theme, prefix) => {
  return getSpacingProperties(theme.tokens?.flexbox, 'margin', 'm', prefix);
};
exports.createMarginClasses = createMarginClasses;
const createPositioningClasses = (prefix = '') => {
  const escapedPrefix = typeof CSS !== 'undefined' ? CSS.escape(prefix) : prefix;
  return `
    .${escapedPrefix}flex-row { flex-direction: row; }
    .${escapedPrefix}flex-row-reverse { flex-direction: row-reverse; }
    .${escapedPrefix}flex-column { flex-direction: column; }
    .${escapedPrefix}flex-column-reverse { flex-direction: column-reverse; }
    .${escapedPrefix}flex { display: flex; }
    .${escapedPrefix}flex-grow { flex: 1; }
    .${escapedPrefix}flex-shrink-1 { flex-shrink: 1; }
    .${escapedPrefix}flex-shrink-0 { flex-shrink: 0; }
    .${escapedPrefix}flex-grow-1 { flex-grow: 1; }
    .${escapedPrefix}flex-grow-0 { flex-grow: 0; }
    .${escapedPrefix}flex-basis-0 { flex-basis: 0; }
    .${escapedPrefix}flex-basis-1 { flex-basis: auto; }
    .${escapedPrefix}align-start { align-items: flex-start; }
    .${escapedPrefix}align-center { align-items: center; }
    .${escapedPrefix}align-right { align-items: flex-end; }
    .${escapedPrefix}align-self-stretch { align-self: stretch; }
    .${escapedPrefix}align-self-center { align-self: center; }
    .${escapedPrefix}align-self-start { align-self: start; }
    .${escapedPrefix}align-self-end { align-self: end; }
    .${escapedPrefix}justify-left { justify-content: flex-start; }
    .${escapedPrefix}justify-center { justify-content: center; }
    .${escapedPrefix}justify-right { justify-content: flex-end; }
    .${escapedPrefix}justify-between { justify-content: space-between; }
    .${escapedPrefix}justify-evenly { justify-content: space-evenly; }
    .${escapedPrefix}justify-arround { justify-content: space-arround; }
    .${escapedPrefix}max-content { width: max-content; }
    .${escapedPrefix}min-content { width: min-content; }
    .${escapedPrefix}gap-0 { gap: 0; }
  `;
};
exports.createPositioningClasses = createPositioningClasses;
const createUtilitaryClasses = theme => {
  return `
  ${createColorClasses(theme)}
  ${createMarginClasses(theme)}
  ${createPaddingClasses(theme)}
  ${createPositioningClasses()}
  
  @media (min-width: ${_mediaQuery.ScreenSizes.SM.min}px) {
    ${createPositioningClasses('sm:')}
    ${createMarginClasses(theme, 'sm:')}
    ${createPaddingClasses(theme, 'sm:')}
  }
  
  @media (min-width: ${_mediaQuery.ScreenSizes.MD.min}px) {
    ${createPositioningClasses('md:')}
    ${createMarginClasses(theme, 'md:')}
    ${createPaddingClasses(theme, 'md:')}
  }
  
  @media (min-width: ${_mediaQuery.ScreenSizes.LG.min}px) {
    ${createPositioningClasses('lg:')}
    ${createMarginClasses(theme, 'lg:')}
    ${createPaddingClasses(theme, 'lg:')}
  }`;
};
exports.createUtilitaryClasses = createUtilitaryClasses;